OptData

Trait OptData 

pub trait OptData {
    // Required method
    fn code(&self) -> OptionCode;
}
A type representing an OPT option.

The type needs to be able to report the option code to use for the encoding via the code method.

Required Methods

fn code(&self) -> OptionCode

Returns the option code associated with this option.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl OptData for ClientSubnet

Source

impl OptData for Expire

Source

impl OptData for TcpKeepalive

Source

impl<Name> OptData for Chain<Name>

Source

impl<Octs, Name> OptData for AllOptData<Octs, Name>

Source

impl<Octs: ?Sized> OptData for KeyTag<Octs>

Source

impl<Octs: ?Sized> OptData for Nsid<Octs>

Source

impl<Octs: ?Sized> OptData for Understood<DauVariant, Octs>

Source

impl<Octs: ?Sized> OptData for Understood<DhuVariant, Octs>

Source

impl<Octs: ?Sized> OptData for Understood<N3uVariant, Octs>

Source

impl<Octs: AsRef<[u8]>> OptData for UnknownOptData<Octs>

Source

impl<Octs> OptData for ExtendedError<Octs>

Source

impl<Octs> OptData for Padding<Octs>