RecordData

Trait RecordData 

pub trait RecordData {
    // Required method
    fn rtype(&self) -> Rtype;
}
A type that represents record data.

The type needs to be able to to be able to provide the record type of a record with a value’s data via the rtype method.

Required Methods

fn rtype(&self) -> Rtype

Returns the record type associated with this record data instance.

This is a method rather than an associated function to allow one type to be used for several real record types.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: RecordData> RecordData for &T

Source

fn rtype(&self) -> Rtype

Implementors

Source

impl RecordData for A

Source

impl RecordData for Aaaa

Source

impl<N> RecordData for Cname<N>

Source

impl<N> RecordData for Dname<N>

Source

impl<N> RecordData for Mb<N>

Source

impl<N> RecordData for Md<N>

Source

impl<N> RecordData for Mf<N>

Source

impl<N> RecordData for Mg<N>

Source

impl<N> RecordData for Minfo<N>

Source

impl<N> RecordData for Mr<N>

Source

impl<N> RecordData for Mx<N>

Source

impl<N> RecordData for Ns<N>

Source

impl<N> RecordData for Ptr<N>

Source

impl<N> RecordData for Soa<N>

Source

impl<N> RecordData for Srv<N>

Source

impl<O, N> RecordData for AllRecordData<O, N>

Source

impl<O, N> RecordData for Tsig<O, N>

Source

impl<O, N> RecordData for ZoneRecordData<O, N>

Source

impl<Octs, Name> RecordData for Naptr<Octs, Name>

Source

impl<Octs, Name> RecordData for Nsec<Octs, Name>

Source

impl<Octs, Name> RecordData for Rrsig<Octs, Name>

Source

impl<Octs, Name> RecordData for SvcbRdata<HttpsVariant, Octs, Name>

Source

impl<Octs, Name> RecordData for SvcbRdata<SvcbVariant, Octs, Name>

Source

impl<Octs: ?Sized> RecordData for Null<Octs>

Source

impl<Octs: ?Sized> RecordData for Opt<Octs>

Source

impl<Octs: AsRef<[u8]>> RecordData for UnknownRecordData<Octs>

Source

impl<Octs> RecordData for Cdnskey<Octs>

Source

impl<Octs> RecordData for Cds<Octs>

Source

impl<Octs> RecordData for Dnskey<Octs>

Source

impl<Octs> RecordData for Ds<Octs>

Source

impl<Octs> RecordData for Hinfo<Octs>

Source

impl<Octs> RecordData for Nsec3<Octs>

Source

impl<Octs> RecordData for Nsec3param<Octs>

Source

impl<Octs> RecordData for Txt<Octs>

Source

impl<Octs> RecordData for Zonemd<Octs>