pub trait FormatWriter: Sized {
// Required methods
fn fmt_token(&mut self, args: Arguments<'_>) -> Result;
fn begin_block(&mut self) -> Result;
fn end_block(&mut self) -> Result;
fn fmt_comment(&mut self, args: Arguments<'_>) -> Result;
fn newline(&mut self) -> Result;
}Expand description
Determines how a zonefile is formatted
Required Methods
Sourcefn begin_block(&mut self) -> Result
fn begin_block(&mut self) -> Result
Start a block of grouped tokens
This might push '(' to the zonefile, but may be ignored by the
PresentationWriter.
Sourcefn end_block(&mut self) -> Result
fn end_block(&mut self) -> Result
End a block of grouped tokens
This might push '(' to the zonefile, but may be ignored by the
PresentationWriter.
Sourcefn fmt_comment(&mut self, args: Arguments<'_>) -> Result
fn fmt_comment(&mut self, args: Arguments<'_>) -> Result
Write a comment
This may be ignored.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".