pub enum Error {
Show 21 variants
ConnectionClosed,
OptTooLong,
MessageBuilderPushError,
MessageParseError,
RedundantTransportNotFound,
FormError,
ShortMessage,
StreamLongMessage,
StreamIdleTimeout,
StreamReceiveError,
StreamReadError(Arc<Error>),
StreamReadTimeout,
StreamTooManyOutstandingQueries,
StreamWriteError(Arc<Error>),
StreamUnexpectedEndOfData,
WrongReplyForQuery,
NoTransportAvailable,
Dgram(Arc<QueryError>),
ZoneWrite,
Authentication(ValidationError),
Validation(Error),
}net and unstable-client-transport only.Expand description
Error type for client transports.
Variants
ConnectionClosed
Connection was already closed.
OptTooLong
The OPT record has become too long.
MessageBuilderPushError
PushError from MessageBuilder.
MessageParseError
ParseError from Message.
RedundantTransportNotFound
Underlying transport not found in redundant connection
FormError
The message violated some constraints.
ShortMessage
Octet sequence too short to be a valid DNS message.
StreamLongMessage
Message too long for stream transport.
StreamIdleTimeout
Stream transport closed because it was idle (for too long).
StreamReceiveError
Error receiving a reply.
StreamReadError(Arc<Error>)
Reading from stream gave an error.
StreamReadTimeout
Reading from stream took too long.
StreamTooManyOutstandingQueries
Too many outstand queries on a single stream transport.
StreamWriteError(Arc<Error>)
Writing to a stream gave an error.
StreamUnexpectedEndOfData
Reading for a stream ended unexpectedly.
WrongReplyForQuery
Reply does not match the query.
NoTransportAvailable
No transport available to transmit request.
Dgram(Arc<QueryError>)
An error happened in the datagram transport.
ZoneWrite
unstable-server-transport only.Zone write failed.
Authentication(ValidationError)
tsig only.TSIG authentication failed.
Validation(Error)
unstable-validator and (crate features openssl or ring) only.An error happened during DNSSEC validation.