Serial

Struct Serial 

#[repr(transparent)]
pub struct Serial(pub U32);
Available on crate feature unstable-new only.
Serial number arithmetic.

Serial implements the “Serial number arithmetic” defined in RFC1982 with a SERIAL_BITS value of 32.

Serial should not be used interchangably or be confused with the SOA Serial Number, which is a Serial but not the sole user of “Serial number arithmetic”.

Tuple Fields

0: U32

Implementations

Source

impl Serial

pub const fn new(value: u32) -> Self

Construct a new Serial

pub const fn get(&self) -> u32

Get u32 value of Serial

pub fn unix_time() -> Self

Available on crate feature std only.

Measure the current time (in seconds) in serial number space.

Source

impl Serial

pub fn inc(self, num: i32) -> Self

Increment this by a non-negative number.

The number must be in the range [0, 2^31 - 1]. An i32 is used instead of a u32 because it is easier to understand and implement a non-negative check versus the upper range check.

Section 7 in RFC1982 states, in particular for the SOA Serial Number, but for any Serial number using a “SERIAL_BITS” value of 32: “The maximum defined increment is 2147483647 (2^31 - 1).”

Panics

Panics if the number is negative.