DName

Struct DName 

#[repr(transparent)]
pub struct DName { pub name: Name, }
Available on crate feature unstable-new only.
Redirection for the descendants of this domain.

A DName record indicates that a doamin name is a (partial!) alias. Queries for data under that domain name (not that domain name itself) are redirected to the specified target. A domain name can have at most one DName record; in this case, it cannot define subordinate records nor have a CName record. It is conceptually similar to CName.

DName is specified by RFC 6672.

Wire Format

The wire format of a DName record is simply the target domain name. This domain name cannot be compressed in DNS messages.

The memory layout of the DName type is identical to its serialization in the wire format. This means that it can be parsed from the wire format in a zero-copy fashion, which is more efficient.

Usage

Because DName is a record data type, it is usually handled within an enum like RecordData. This section describes how to use it independently (or when building new record data from scratch).

DName is a dynamically sized type (DST). It is not possible to store an DName in place (e.g. in a local variable); it must be held indirectly, via a reference or a smart pointer type like Box. This makes it more difficult to create new DNames; but once they are placed somewhere, they can be used by reference (i.e. &DName) exactly like any other type.

It is currently a bit difficult to build a new DName from scratch. It is easiest to use DName::new() on a reference to a Name, or to build the wire format representation of the DName manually and then to parse it.

// Parse a 'Name' and build a 'DName' from there:
let name = "example.org.".parse::<NameBuf>().unwrap();
let dname = DName::new(&name);

// Parse a 'DName' from the DNS wire format:
let bytes = b"\x07example\x03org\x00";
let from_bytes: &DName = <&DName>::parse_bytes(bytes).unwrap();
assert_eq!(dname.as_bytes(), bytes);

// Copy a 'DName' onto the heap:
let heaped: Box<DName> = dname.unsized_copy_into();

As a DST, DName does not implement Copy or Clone. Instead, it implements UnsizedCopy. A DName, held by reference, can be copied into a different container (e.g. Box) using unsized_copy_into()

For debugging, DName can be formatted using fmt::Debug.

To serialize a DName in the wire format, use BuildBytes (which will serialize it to a given buffer) or AsBytes (which will cast the DName into a byte sequence in place). It also supports BuildInMessage.

Fields

name: Name

The target name.

Implementations

Source

impl DName

pub const fn new(target: &Name) -> &Self

Wrap a domain name as a DName.