pub struct ServerError<K>(/* private fields */);Available on crate feature
tsig only.Expand description
A TSIG record of a received request couldn’t be validated.
A value of this type carries all information necessary to produce the error response to be send back to the client.
Implementations
Sourceimpl<K: AsRef<Key>> ServerError<K>
impl<K: AsRef<Key>> ServerError<K>
pub fn build_message<Octs, Target>( self, msg: &Message<Octs>, builder: MessageBuilder<Target>, ) -> Result<AdditionalBuilder<Target>, PushError>