Crate css [−] [src]
Reexports
pub extern crate cssparser; |
pub extern crate ordermap; |
pub extern crate smallvec; |
Modules
| domain | |
| selectors | |
| servo_arc |
Fork of Arc for Servo. This has the following advantages over std::Arc: * We don't waste storage on the weak reference count. * We don't do extra RMU operations to handle the possibility of weak references. * We can experiment with arena allocation (todo). * We can add methods to support our custom use cases [1]. * We have support for dynamically-sized types (see from_header_and_iter). * We have support for thin arcs to unsized types (see ThinArc). |
Macros
| __define_css_keyword_enum__actual | |
| __define_css_keyword_enum__add_optional_traits | |
| define_css_keyword_enum |
Structs
| Stylesheet |
Enums
| CustomParseError |