pub trait RecordData {
// Required method
fn rtype(&self) -> Rtype;
}Expand description
A type that represents record data.
The type needs to be able to to be able to provide the record type of a
record with a value’s data via the rtype method.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".