#[non_exhaustive]pub enum RecordData<'a, N> {
Show 21 variants
A(A),
Ns(Ns<N>),
CName(CName<N>),
Soa(Soa<N>),
Ptr(Ptr<N>),
HInfo(HInfo<'a>),
Mx(Mx<N>),
Txt(&'a Txt),
Rp(Rp<N>),
Srv(&'a Srv),
Aaaa(Aaaa),
DName(&'a DName),
Opt(&'a Opt),
Ds(&'a Ds),
Rrsig(Rrsig<'a>),
Nsec(Nsec<'a>),
DNSKey(&'a DNSKey),
Nsec3(Nsec3<'a>),
Nsec3Param(&'a Nsec3Param),
ZoneMD(&'a ZoneMD),
Unknown(RType, &'a UnknownRecordData),
}unstable-new only.Expand description
DNS record data.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
A(A)
The IPv4 address of a host responsible for this domain.
Ns(Ns<N>)
The authoritative name server for this domain.
CName(CName<N>)
The canonical name for this domain.
Soa(Soa<N>)
The start of a zone of authority.
Ptr(Ptr<N>)
A pointer to another domain name.
HInfo(HInfo<'a>)
Information about the host computer.
Mx(Mx<N>)
A host that can exchange mail for this domain.
Txt(&'a Txt)
Free-form text strings about this domain.
Rp(Rp<N>)
Identification of the person/party responsible for this domain.
Srv(&'a Srv)
The locations of services associated with this domain.
Aaaa(Aaaa)
The IPv6 address of a host responsible for this domain.
DName(&'a DName)
Redirection for the descendants of this domain.
Opt(&'a Opt)
Extended DNS options.
Ds(&'a Ds)
The signing key of a delegated zone.
Rrsig(Rrsig<'a>)
A cryptographic signature on a DNS record set.
Nsec(Nsec<'a>)
An indication of the non-existence of a set of DNS records (version 1).
DNSKey(&'a DNSKey)
A cryptographic key for DNS security.
Nsec3(Nsec3<'a>)
An indication of the non-existence of a set of DNS records (version 3).
Nsec3Param(&'a Nsec3Param)
Parameters for computing Nsec3 records.
ZoneMD(&'a ZoneMD)
A message digest of the enclosing zone.
Unknown(RType, &'a UnknownRecordData)
Data for an unknown DNS record type.
Implementations
Sourceimpl<'a, N> RecordData<'a, N>
impl<'a, N> RecordData<'a, N>
Sourcepub fn map_names<R, F: FnMut(N) -> R>(self, f: F) -> RecordData<'a, R>
pub fn map_names<R, F: FnMut(N) -> R>(self, f: F) -> RecordData<'a, R>
Map the domain names within to another type.
Sourcepub fn map_names_by_ref<'r, R, F: FnMut(&'r N) -> R>(
&'r self,
f: F,
) -> RecordData<'r, R>
pub fn map_names_by_ref<'r, R, F: FnMut(&'r N) -> R>( &'r self, f: F, ) -> RecordData<'r, R>
Map references to the domain names within to another type.
Sourcepub fn clone_to_bump<'r>(&self, bump: &'r Bump) -> RecordData<'r, N>where
N: Clone,
Available on crate feature bumpalo only.
pub fn clone_to_bump<'r>(&self, bump: &'r Bump) -> RecordData<'r, N>where
N: Clone,
bumpalo only.Copy referenced data into the given Bump allocator.