#[repr(transparent)]pub struct Ptr<N> {
pub name: N,
}unstable-new only.Expand description
A pointer to another domain name.
A Ptr record is used with special domain names for pointing to other
locations in the domain name space. It is conventionally used for reverse
lookups: for example, the Ptr record for <addr>.in-addr.arpa points
to the domain name using the IPv4 <addr> in an A record. The same
technique works with <addr>.ip6.arpa for IPv6 addresses.
Ptr is specified by RFC 1035, section 3.3.12.
Wire format
The wire format of a Ptr record is simply the domain name of the name
server. This domain name may be compressed in DNS messages.
Usage
Because Ptr is a record data type, it is usually handled within
an enum like RecordData. This section describes how to use it
independently (or when building new record data from scratch).
In order to build a Ptr, it’s first important to choose a domain name
type. For short-term usage (where the Ptr is a local variable), it is
common to pick RevNameBuf. If the Ptr will be placed on the heap,
Box< will be more efficient.RevName>
The primary way to build a new Ptr is to construct each field manually.
To parse a Ptr from a DNS message, use ParseMessageBytes. In case
the input bytes don’t use name compression, ParseBytes can be used.
// Build a 'Ptr' manually:
let manual: Ptr<RevNameBuf> = Ptr {
name: "example.org.".parse().unwrap(),
};
// Its wire format serialization looks like:
let bytes = b"\x07example\x03org\x00";
// Parse a 'Ptr' from the wire format, without name decompression:
let from_wire: Ptr<RevNameBuf> = Ptr::parse_bytes(bytes).unwrap();
// See 'ParseMessageBytes' for parsing with name decompression.Since Ptr is a sized type, and it implements Copy and Clone,
it’s straightforward to handle and move around. However, this depends on
the domain name type. It can be changed using Ptr::map_name() and
Ptr::map_name_by_ref().
For debugging, Ptr can be formatted using fmt::Debug.
To serialize a Ptr in the wire format, use BuildInMessage (which
supports name compression). If name compression is not desired, use
BuildBytes.
Fields
name: NThe referenced domain name.
Implementations